# BASE_URL = "https://diavgeia.gov.gr/api"
# για το παραγωγικό σύστημα το API_BASE_URL είναι το https://diavgeia.gov.gr/opendata
BASE_URL = "https://diavgeia.gov.gr/opendata"

DEFAULT_HEADERS = {
    "Accept": "application/json",
}

# path constants
TYPES = "types"
DECISIONS = "decisions"
ORGANIZATIONS = "organizations"
SEARCH = "search"
SIGNERS = "signers"
POSITIONS = "positions"
DICTIONARIES = "dictionaries"
UNITS = "units"

WANTED_DATE_FORMAT = "%Y-%m-%d"
